@@ -1,7 +1,7 @@
 /* valaccodememberaccess.vala
  *
  * Copyright (C) 2006  Raffaele Sandrini
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -47,9 +47,9 @@ static void vala_ccode_element_access_finalize (ValaCCodeNode* obj);
 
 ValaCCodeElementAccess* vala_ccode_element_access_construct (GType object_type, ValaCCodeExpression* cont, ValaCCodeExpression* i) {
 	ValaCCodeElementAccess* self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cont), NULL);
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (i), NULL);
-	self = ((ValaCCodeElementAccess*) (g_type_create_instance (object_type)));
+	g_return_val_if_fail (cont != NULL, NULL);
+	g_return_val_if_fail (i != NULL, NULL);
+	self = (ValaCCodeElementAccess*) g_type_create_instance (object_type);
 	vala_ccode_element_access_set_container (self, cont);
 	vala_ccode_element_access_set_index (self, i);
 	return self;
@@ -63,17 +63,17 @@ ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont
 
 static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeElementAccess * self;
-	self = VALA_CCODE_ELEMENT_ACCESS (base);
-	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_container), writer);
+	self = (ValaCCodeElementAccess*) base;
+	g_return_if_fail (writer != NULL);
+	vala_ccode_expression_write_inner (self->priv->_container, writer);
 	vala_ccode_writer_write_string (writer, "[");
-	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_index), writer);
+	vala_ccode_node_write ((ValaCCodeNode*) self->priv->_index, writer);
 	vala_ccode_writer_write_string (writer, "]");
 }
 
 
 ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAccess* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_container;
 }
 
@@ -81,15 +81,15 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL))), _tmp2);
+	self->priv->_container = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)), _tmp2);
 }
 
 
 ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess* self) {
-	g_return_val_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_index;
 }
 
@@ -97,10 +97,10 @@ ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value) {
 	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
-	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_index = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_index == NULL ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL))), _tmp2);
+	self->priv->_index = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_ccode_node_ref (_tmp1)), (self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)), _tmp2);
 }
 
 
@@ -120,8 +120,8 @@ static void vala_ccode_element_access_instance_init (ValaCCodeElementAccess * se
 static void vala_ccode_element_access_finalize (ValaCCodeNode* obj) {
 	ValaCCodeElementAccess * self;
 	self = VALA_CCODE_ELEMENT_ACCESS (obj);
-	(self->priv->_container == NULL ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL)));
-	(self->priv->_index == NULL ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL)));
+	(self->priv->_container == NULL) ? NULL : (self->priv->_container = (vala_ccode_node_unref (self->priv->_container), NULL));
+	(self->priv->_index == NULL) ? NULL : (self->priv->_index = (vala_ccode_node_unref (self->priv->_index), NULL));
 	VALA_CCODE_NODE_CLASS (vala_ccode_element_access_parent_class)->finalize (obj);
 }
 
