@@ -52,6 +52,7 @@ struct _GeeArrayListIteratorClass {
 struct _GeeArrayListPrivate {
 	gpointer* _items;
 	gint _items_length1;
+	gint _items_size;
 	gint _size;
 	GEqualFunc _equal_func;
 	gint _stamp;
@@ -525,14 +526,10 @@ GType gee_array_list_get_type (void) {
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
-		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
-		}
-		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) array)[i] != NULL) {
+				destroy_func (((gpointer*) array)[i]);
+			}
 		}
 	}
 	g_free (array);
