@@ -35,12 +35,12 @@ typedef struct _GeeReadOnlyListIteratorClass GeeReadOnlyListIteratorClass;
 typedef struct _GeeReadOnlyListIteratorPrivate GeeReadOnlyListIteratorPrivate;
 
 struct _GeeReadOnlyListIterator {
-	GObject parent_instance;
+	GeeCollectionObject parent_instance;
 	GeeReadOnlyListIteratorPrivate * priv;
 };
 
 struct _GeeReadOnlyListIteratorClass {
-	GObjectClass parent_class;
+	GeeCollectionObjectClass parent_class;
 };
 
 
@@ -54,12 +54,7 @@ struct _GeeReadOnlyListPrivate {
 
 #define GEE_READ_ONLY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListPrivate))
 enum  {
-	GEE_READ_ONLY_LIST_DUMMY_PROPERTY,
-	GEE_READ_ONLY_LIST_SIZE,
-	GEE_READ_ONLY_LIST_LIST,
-	GEE_READ_ONLY_LIST_G_TYPE,
-	GEE_READ_ONLY_LIST_G_DUP_FUNC,
-	GEE_READ_ONLY_LIST_G_DESTROY_FUNC
+	GEE_READ_ONLY_LIST_DUMMY_PROPERTY
 };
 static GType gee_read_only_list_real_get_element_type (GeeIterable* base);
 static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base);
@@ -80,13 +75,11 @@ struct _GeeReadOnlyListIteratorPrivate {
 
 #define GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIteratorPrivate))
 enum  {
-	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY,
-	GEE_READ_ONLY_LIST_ITERATOR_G_TYPE,
-	GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC,
-	GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC
+	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY
 };
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base);
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func);
 static gpointer gee_read_only_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_read_only_list_iterator_gee_iterator_parent_iface = NULL;
@@ -95,70 +88,56 @@ static gpointer gee_read_only_list_parent_class = NULL;
 static GeeIterableIface* gee_read_only_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_read_only_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_read_only_list_gee_list_parent_iface = NULL;
-static void gee_read_only_list_finalize (GObject * obj);
+static void gee_read_only_list_finalize (GeeCollectionObject* obj);
 
 
 
+GeeReadOnlyList* gee_read_only_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
+	GeeReadOnlyList* self;
+	self = (GeeReadOnlyList*) g_type_create_instance (object_type);
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
+	gee_read_only_list_set_list (self, list);
+	return self;
+}
+
+
 GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyList * self;
-	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_TYPE_READ_ONLY_LIST, __params_it - __params, __params);
-	gee_read_only_list_set_list (self, list);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
-	return self;
+	return gee_read_only_list_construct (GEE_TYPE_READ_ONLY_LIST, g_type, g_dup_func, g_destroy_func, list);
 }
 
 
 static GType gee_read_only_list_real_get_element_type (GeeIterable* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	return self->priv->g_type;
 }
 
 
 static GeeIterator* gee_read_only_list_real_iterator (GeeIterable* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
-		return GEE_ITERATOR (gee_read_only_list_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
+		return (GeeIterator*) gee_read_only_list_iterator_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func);
 	}
-	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_list));
+	return gee_iterable_iterator ((GeeIterable*) self->priv->_list);
 }
 
 
 static gboolean gee_read_only_list_real_contains (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return FALSE;
 	}
-	return gee_collection_contains (GEE_COLLECTION (self->priv->_list), item);
+	return gee_collection_contains ((GeeCollection*) self->priv->_list, item);
 }
 
 
 static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return -1;
 	}
@@ -168,35 +147,35 @@ static gint gee_read_only_list_real_index_of (GeeList* base, gconstpointer item)
 
 static gboolean gee_read_only_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gboolean gee_read_only_list_real_remove (GeeCollection* base, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_insert (GeeList* base, gint index, gconstpointer item) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_remove_at (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gpointer gee_read_only_list_real_get (GeeList* base, gint index) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	if (self->priv->_list == NULL) {
 		return NULL;
 	}
@@ -206,117 +185,67 @@ static gpointer gee_read_only_list_real_get (GeeList* base, gint index) {
 
 static void gee_read_only_list_real_set (GeeList* base, gint index, gconstpointer o) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static void gee_read_only_list_real_clear (GeeCollection* base) {
 	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (base);
+	self = (GeeReadOnlyList*) base;
 	g_assert_not_reached ();
 }
 
 
 static gint gee_read_only_list_real_get_size (GeeCollection* base) {
 	GeeReadOnlyList* self;
-	self = GEE_READ_ONLY_LIST (base);
-	return gee_collection_get_size (GEE_COLLECTION (self->priv->_list));
+	self = (GeeReadOnlyList*) base;
+	return gee_collection_get_size ((GeeCollection*) self->priv->_list);
 }
 
 
 void gee_read_only_list_set_list (GeeReadOnlyList* self, GeeList* value) {
 	GeeList* _tmp1;
 	GeeList* _tmp0;
-	g_return_if_fail (GEE_IS_READ_ONLY_LIST (self));
+	g_return_if_fail (self != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL))), _tmp1);
-	g_object_notify (((GObject *) (self)), "list");
+	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1);
 }
 
 
 static gboolean gee_read_only_list_iterator_real_next (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (base);
+	self = (GeeReadOnlyListIterator*) base;
 	return FALSE;
 }
 
 
 static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (base);
+	self = (GeeReadOnlyListIterator*) base;
 	return NULL;
 }
 
 
-static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
-	GParameter * __params;
-	GParameter * __params_it;
-	GeeReadOnlyListIterator * self;
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	__params_it->name = "g-type";
-	g_value_init (&__params_it->value, G_TYPE_GTYPE);
-	g_value_set_gtype (&__params_it->value, g_type);
-	__params_it++;
-	__params_it->name = "g-dup-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_dup_func);
-	__params_it++;
-	__params_it->name = "g-destroy-func";
-	g_value_init (&__params_it->value, G_TYPE_POINTER);
-	g_value_set_pointer (&__params_it->value, g_destroy_func);
-	__params_it++;
-	self = g_object_newv (GEE_READ_ONLY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GeeReadOnlyListIterator* self;
+	self = (GeeReadOnlyListIterator*) g_type_create_instance (object_type);
+	self->priv->g_type = g_type;
+	self->priv->g_dup_func = g_dup_func;
+	self->priv->g_destroy_func = g_destroy_func;
 	return self;
 }
 
 
-static void gee_read_only_list_iterator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (object);
-	switch (property_id) {
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_list_iterator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyListIterator * self;
-	self = GEE_READ_ONLY_LIST_ITERATOR (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_ITERATOR_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
+static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	return gee_read_only_list_iterator_construct (GEE_READ_ONLY_LIST_TYPE_ITERATOR, g_type, g_dup_func, g_destroy_func);
 }
 
 
 static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass * klass) {
 	gee_read_only_list_iterator_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListIteratorPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_iterator_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -335,63 +264,19 @@ static void gee_read_only_list_iterator_instance_init (GeeReadOnlyListIterator *
 static GType gee_read_only_list_iterator_get_type (void) {
 	static GType gee_read_only_list_iterator_type_id = 0;
 	if (gee_read_only_list_iterator_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyListIterator), 0, (GInstanceInitFunc) gee_read_only_list_iterator_instance_init, NULL };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_list_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_list_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyListIterator", &g_define_type_info, 0);
+		gee_read_only_list_iterator_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyListIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_list_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
 	}
 	return gee_read_only_list_iterator_type_id;
 }
 
 
-static void gee_read_only_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_SIZE:
-		g_value_set_int (value, gee_collection_get_size (GEE_COLLECTION (self)));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void gee_read_only_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	GeeReadOnlyList * self;
-	self = GEE_READ_ONLY_LIST (object);
-	switch (property_id) {
-		case GEE_READ_ONLY_LIST_LIST:
-		gee_read_only_list_set_list (self, g_value_get_object (value));
-		break;
-		case GEE_READ_ONLY_LIST_G_TYPE:
-		self->priv->g_type = g_value_get_gtype (value);
-		break;
-		case GEE_READ_ONLY_LIST_G_DUP_FUNC:
-		self->priv->g_dup_func = g_value_get_pointer (value);
-		break;
-		case GEE_READ_ONLY_LIST_G_DESTROY_FUNC:
-		self->priv->g_destroy_func = g_value_get_pointer (value);
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass) {
 	gee_read_only_list_parent_class = g_type_class_peek_parent (klass);
+	GEE_COLLECTION_OBJECT_CLASS (klass)->finalize = gee_read_only_list_finalize;
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListPrivate));
-	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_get_property;
-	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_set_property;
-	G_OBJECT_CLASS (klass)->finalize = gee_read_only_list_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_SIZE, "size");
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
 
@@ -427,22 +312,22 @@ static void gee_read_only_list_instance_init (GeeReadOnlyList * self) {
 }
 
 
-static void gee_read_only_list_finalize (GObject * obj) {
+static void gee_read_only_list_finalize (GeeCollectionObject* obj) {
 	GeeReadOnlyList * self;
 	self = GEE_READ_ONLY_LIST (obj);
-	(self->priv->_list == NULL ? NULL : (self->priv->_list = (g_object_unref (self->priv->_list), NULL)));
-	G_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
+	(self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL));
+	GEE_COLLECTION_OBJECT_CLASS (gee_read_only_list_parent_class)->finalize (obj);
 }
 
 
 GType gee_read_only_list_get_type (void) {
 	static GType gee_read_only_list_type_id = 0;
 	if (gee_read_only_list_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyList), 0, (GInstanceInitFunc) gee_read_only_list_instance_init, NULL };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_list_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_list_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_list_info = { (GInterfaceInitFunc) gee_read_only_list_gee_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
-		gee_read_only_list_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyList", &g_define_type_info, 0);
+		gee_read_only_list_type_id = g_type_register_static (GEE_TYPE_COLLECTION_OBJECT, "GeeReadOnlyList", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_ITERABLE, &gee_iterable_info);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_COLLECTION, &gee_collection_info);
 		g_type_add_interface_static (gee_read_only_list_type_id, GEE_TYPE_LIST, &gee_list_info);
