@@ -1,6 +1,6 @@
 /* valacodenode.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -171,7 +171,7 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 static gboolean vala_code_node_real_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (analyzer != NULL, FALSE);
-	return FALSE;
+	return TRUE;
 }
 
 
@@ -296,6 +296,12 @@ char* vala_code_node_get_temp_name (ValaCodeNode* self) {
 }
 
 
+const char* vala_code_node_get_type_name (ValaCodeNode* self) {
+	g_return_val_if_fail (self != NULL, NULL);
+	return g_type_name (G_TYPE_FROM_INSTANCE (self));
+}
+
+
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self) {
 	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_parent_node;
