@@ -1,6 +1,6 @@
 /* valaenumvalue.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 #include <vala/valaenum.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valamemberaccess.h>
+#include <vala/valasourcefile.h>
 
 
 
@@ -41,6 +44,7 @@ enum  {
 };
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_enum_value_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_enum_value_parent_class = NULL;
 static void vala_enum_value_finalize (ValaCodeNode* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -56,11 +60,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 ValaEnumValue* vala_enum_value_construct (GType object_type, const char* name, ValaSourceReference* source_reference) {
 	ValaEnumValue* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = ((ValaEnumValue*) (g_type_create_instance (object_type)));
-	vala_symbol_init (VALA_SYMBOL (self));
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	self = (ValaEnumValue*) vala_symbol_construct (object_type, name, source_reference);
 	return self;
 }
 
@@ -80,13 +80,9 @@ ValaEnumValue* vala_enum_value_new (const char* name, ValaSourceReference* sourc
 ValaEnumValue* vala_enum_value_construct_with_value (GType object_type, const char* name, ValaExpression* value, ValaSourceReference* source_reference) {
 	ValaEnumValue* self;
 	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_EXPRESSION (value), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = ((ValaEnumValue*) (g_type_create_instance (object_type)));
-	vala_symbol_init (VALA_SYMBOL (self));
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	g_return_val_if_fail (value != NULL, NULL);
+	self = (ValaEnumValue*) vala_enum_value_construct (object_type, name, source_reference);
 	vala_enum_value_set_value (self, value);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -107,10 +103,10 @@ ValaCCodeConstant* vala_enum_value_get_canonical_cconstant (ValaEnumValue* self)
 	const char* _tmp0;
 	char* i;
 	ValaCCodeConstant* _tmp3;
-	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("\"");
 	_tmp0 = NULL;
-	i = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	i = (_tmp0 = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
 		char* _tmp2;
@@ -123,28 +119,28 @@ ValaCCodeConstant* vala_enum_value_get_canonical_cconstant (ValaEnumValue* self)
 		}
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
+		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), i = (g_free (i), NULL), _tmp2);
 	}
 	g_string_append_c (str, '"');
 	_tmp3 = NULL;
-	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
+	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp3);
 }
 
 
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnumValue * self;
-	self = VALA_ENUM_VALUE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaEnumValue*) base;
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_enum_value (visitor, self);
 }
 
 
 static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnumValue * self;
-	self = VALA_ENUM_VALUE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaEnumValue*) base;
+	g_return_if_fail (visitor != NULL);
 	if (self->priv->_value != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (self->priv->_value), visitor);
+		vala_code_node_accept ((ValaCodeNode*) self->priv->_value, visitor);
 	}
 }
 
@@ -153,23 +149,30 @@ static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVi
  * Process all associated attributes.
  */
 void vala_enum_value_process_attributes (ValaEnumValue* self) {
-	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
+	g_return_if_fail (self != NULL);
 	{
 		GList* a_collection;
 		GList* a_it;
-		a_collection = VALA_CODE_NODE (self)->attributes;
+		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp1;
+			ValaAttribute* _tmp2;
 			ValaAttribute* a;
-			_tmp1 = NULL;
-			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1)));
+			_tmp2 = NULL;
+			a = (_tmp2 = (ValaAttribute*) a_it->data, (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
 			{
-				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0 && vala_attribute_has_argument (a, "cname")) {
-					char* _tmp0;
-					_tmp0 = NULL;
-					self->priv->cname = (_tmp0 = vala_attribute_get_string (a, "cname"), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+				gboolean _tmp0;
+				_tmp0 = FALSE;
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
+					_tmp0 = vala_attribute_has_argument (a, "cname");
+				} else {
+					_tmp0 = FALSE;
 				}
-				(a == NULL ? NULL : (a = (vala_code_node_unref (a), NULL)));
+				if (_tmp0) {
+					char* _tmp1;
+					_tmp1 = NULL;
+					self->priv->cname = (_tmp1 = vala_attribute_get_string (a, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+				}
+				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
 			}
 		}
 	}
@@ -183,14 +186,14 @@ void vala_enum_value_process_attributes (ValaEnumValue* self) {
  */
 char* vala_enum_value_get_cname (ValaEnumValue* self) {
 	const char* _tmp1;
-	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = vala_enum_value_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+		self->priv->cname = (_tmp0 = vala_enum_value_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0);
 	}
 	_tmp1 = NULL;
-	return (_tmp1 = self->priv->cname, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+	return (_tmp1 = self->priv->cname, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
 }
 
 
@@ -200,13 +203,13 @@ char* vala_enum_value_get_default_cname (ValaEnumValue* self) {
 	char* _tmp1;
 	char* _tmp2;
 	char* _tmp3;
-	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0 = NULL;
-	en = (_tmp0 = VALA_ENUM (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
+	en = (_tmp0 = VALA_ENUM (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
 	_tmp1 = NULL;
 	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = g_strdup_printf ("%s%s", (_tmp1 = vala_enum_get_cprefix (en)), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2), (en == NULL ? NULL : (en = (vala_code_node_unref (en), NULL))), _tmp3);
+	return (_tmp3 = (_tmp2 = g_strdup_printf ("%s%s", _tmp1 = vala_enum_get_cprefix (en), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1 = (g_free (_tmp1), NULL), _tmp2), (en == NULL) ? NULL : (en = (vala_code_node_unref (en), NULL)), _tmp3);
 }
 
 
@@ -218,16 +221,50 @@ char* vala_enum_value_get_default_cname (ValaEnumValue* self) {
 void vala_enum_value_set_cname (ValaEnumValue* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
-	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
+	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
+	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+}
+
+
+static gboolean vala_enum_value_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaEnumValue * self;
+	self = (ValaEnumValue*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	vala_enum_value_process_attributes (self);
+	if (self->priv->_value != NULL) {
+		gboolean _tmp1;
+		gboolean _tmp2;
+		vala_code_node_check ((ValaCodeNode*) self->priv->_value, analyzer);
+		_tmp1 = FALSE;
+		_tmp2 = FALSE;
+		if (!vala_symbol_is_internal_symbol (vala_symbol_get_parent_symbol ((ValaSymbol*) self))) {
+			_tmp2 = VALA_IS_MEMBER_ACCESS (self->priv->_value);
+		} else {
+			_tmp2 = FALSE;
+		}
+		if (_tmp2) {
+			_tmp1 = vala_expression_get_symbol_reference (self->priv->_value) != NULL;
+		} else {
+			_tmp1 = FALSE;
+		}
+		/* ensure to include dependency in header file as well if necessary*/
+		if (_tmp1) {
+			vala_source_file_add_symbol_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_expression_get_symbol_reference (self->priv->_value), VALA_SOURCE_FILE_DEPENDENCY_TYPE_HEADER_SHALLOW);
+		}
+	}
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
 
 
 ValaExpression* vala_enum_value_get_value (ValaEnumValue* self) {
-	g_return_val_if_fail (VALA_IS_ENUM_VALUE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_value;
 }
 
@@ -235,10 +272,10 @@ ValaExpression* vala_enum_value_get_value (ValaEnumValue* self) {
 void vala_enum_value_set_value (ValaEnumValue* self, ValaExpression* value) {
 	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
-	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_value == NULL ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL))), _tmp2);
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL)), _tmp2);
 }
 
 
@@ -248,6 +285,7 @@ static void vala_enum_value_class_init (ValaEnumValueClass * klass) {
 	g_type_class_add_private (klass, sizeof (ValaEnumValuePrivate));
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_value_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_value_real_accept_children;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_enum_value_real_check;
 }
 
 
@@ -259,7 +297,7 @@ static void vala_enum_value_instance_init (ValaEnumValue * self) {
 static void vala_enum_value_finalize (ValaCodeNode* obj) {
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (obj);
-	(self->priv->_value == NULL ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL)));
+	(self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	VALA_CODE_NODE_CLASS (vala_enum_value_parent_class)->finalize (obj);
 }
@@ -280,7 +318,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2) {
 		return -(str1 != str2);
 	}
 	if (str2 == NULL) {
-		return (str1 != str2);
+		return str1 != str2;
 	}
 	return strcmp (str1, str2);
 }
