@@ -1,6 +1,6 @@
 /* valamemberaccess.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -274,8 +274,8 @@ static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataTy
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) self->priv->type_argument_list, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) self->priv->type_argument_list, i, new_type);
+			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (self->priv->type_argument_list, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (self->priv->type_argument_list, i, new_type);
 				return;
 			}
 		}
@@ -319,14 +319,14 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 	ValaSymbol* base_symbol;
 	ValaFormalParameter* this_parameter;
 	gboolean may_access_instance_members;
-	ValaSymbol* _tmp75;
+	ValaSymbol* _tmp76;
 	ValaSymbol* member;
 	ValaSymbolAccessibility access;
 	gboolean instance;
 	gboolean klass;
-	gboolean _tmp96;
 	gboolean _tmp97;
-	gboolean _tmp129;
+	gboolean _tmp98;
+	gboolean _tmp130;
 	self = (ValaMemberAccess*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -737,7 +737,7 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 								prop = vala_dynamic_property_new (vala_expression_get_value_type (vala_member_access_get_inner (self)), self->priv->_member_name, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 								vala_symbol_set_access ((ValaSymbol*) prop, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 								_tmp67 = NULL;
-								vala_property_set_set_accessor ((ValaProperty*) prop, _tmp67 = vala_property_accessor_new (FALSE, TRUE, FALSE, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) prop)));
+								vala_property_set_set_accessor ((ValaProperty*) prop, _tmp67 = vala_property_accessor_new (FALSE, TRUE, FALSE, NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) prop)));
 								(_tmp67 == NULL) ? NULL : (_tmp67 = (vala_code_node_unref (_tmp67), NULL));
 								vala_property_accessor_set_access (vala_property_get_set_accessor ((ValaProperty*) prop), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 								vala_symbol_set_owner ((ValaSymbol*) prop, vala_symbol_get_scope ((ValaSymbol*) vala_data_type_get_data_type (vala_expression_get_value_type (vala_member_access_get_inner (self)))));
@@ -751,7 +751,8 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 				}
 				if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
 					ValaDynamicProperty* prop;
-					ValaPropertyAccessor* _tmp69;
+					ValaPropertyAccessor* _tmp70;
+					ValaDataType* _tmp69;
 					/* dynamic property read access*/
 					prop = vala_dynamic_property_new (vala_expression_get_value_type (vala_member_access_get_inner (self)), self->priv->_member_name, vala_code_node_get_source_reference ((ValaCodeNode*) self));
 					if (vala_expression_get_target_type ((ValaExpression*) self) != NULL) {
@@ -764,8 +765,10 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 						(_tmp68 == NULL) ? NULL : (_tmp68 = (vala_code_node_unref (_tmp68), NULL));
 					}
 					vala_symbol_set_access ((ValaSymbol*) prop, VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
+					_tmp70 = NULL;
 					_tmp69 = NULL;
-					vala_property_set_get_accessor ((ValaProperty*) prop, _tmp69 = vala_property_accessor_new (TRUE, FALSE, FALSE, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) prop)));
+					vala_property_set_get_accessor ((ValaProperty*) prop, _tmp70 = vala_property_accessor_new (TRUE, FALSE, FALSE, _tmp69 = vala_data_type_copy (vala_property_get_property_type ((ValaProperty*) prop)), NULL, vala_code_node_get_source_reference ((ValaCodeNode*) prop)));
+					(_tmp70 == NULL) ? NULL : (_tmp70 = (vala_code_node_unref (_tmp70), NULL));
 					(_tmp69 == NULL) ? NULL : (_tmp69 = (vala_code_node_unref (_tmp69), NULL));
 					vala_property_accessor_set_access (vala_property_get_get_accessor ((ValaProperty*) prop), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 					vala_symbol_set_owner ((ValaSymbol*) prop, vala_symbol_get_scope ((ValaSymbol*) vala_data_type_get_data_type (vala_expression_get_value_type (vala_member_access_get_inner (self)))));
@@ -782,57 +785,57 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 	}
 	if (vala_expression_get_symbol_reference ((ValaExpression*) self) == NULL) {
 		char* base_type_name;
-		gboolean _tmp70;
-		char* _tmp73;
-		gboolean _tmp74;
+		gboolean _tmp71;
+		char* _tmp74;
+		gboolean _tmp75;
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		base_type_name = g_strdup ("(null)");
-		_tmp70 = FALSE;
+		_tmp71 = FALSE;
 		if (vala_member_access_get_inner (self) != NULL) {
-			_tmp70 = vala_expression_get_value_type (vala_member_access_get_inner (self)) != NULL;
+			_tmp71 = vala_expression_get_value_type (vala_member_access_get_inner (self)) != NULL;
 		} else {
-			_tmp70 = FALSE;
+			_tmp71 = FALSE;
 		}
-		if (_tmp70) {
-			char* _tmp71;
-			_tmp71 = NULL;
-			base_type_name = (_tmp71 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_member_access_get_inner (self))), base_type_name = (g_free (base_type_name), NULL), _tmp71);
+		if (_tmp71) {
+			char* _tmp72;
+			_tmp72 = NULL;
+			base_type_name = (_tmp72 = vala_code_node_to_string ((ValaCodeNode*) vala_expression_get_value_type (vala_member_access_get_inner (self))), base_type_name = (g_free (base_type_name), NULL), _tmp72);
 		} else {
 			if (base_symbol != NULL) {
-				char* _tmp72;
-				_tmp72 = NULL;
-				base_type_name = (_tmp72 = vala_symbol_get_full_name (base_symbol), base_type_name = (g_free (base_type_name), NULL), _tmp72);
+				char* _tmp73;
+				_tmp73 = NULL;
+				base_type_name = (_tmp73 = vala_symbol_get_full_name (base_symbol), base_type_name = (g_free (base_type_name), NULL), _tmp73);
 			}
 		}
-		_tmp73 = NULL;
-		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp73 = g_strdup_printf ("The name `%s' does not exist in the context of `%s'", self->priv->_member_name, base_type_name));
-		_tmp73 = (g_free (_tmp73), NULL);
-		return (_tmp74 = FALSE, base_type_name = (g_free (base_type_name), NULL), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), _tmp74);
+		_tmp74 = NULL;
+		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp74 = g_strdup_printf ("The name `%s' does not exist in the context of `%s'", self->priv->_member_name, base_type_name));
+		_tmp74 = (g_free (_tmp74), NULL);
+		return (_tmp75 = FALSE, base_type_name = (g_free (base_type_name), NULL), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), _tmp75);
 	}
-	_tmp75 = NULL;
-	member = (_tmp75 = vala_expression_get_symbol_reference ((ValaExpression*) self), (_tmp75 == NULL) ? NULL : vala_code_node_ref (_tmp75));
+	_tmp76 = NULL;
+	member = (_tmp76 = vala_expression_get_symbol_reference ((ValaExpression*) self), (_tmp76 == NULL) ? NULL : vala_code_node_ref (_tmp76));
 	access = VALA_SYMBOL_ACCESSIBILITY_PUBLIC;
 	instance = FALSE;
 	klass = FALSE;
 	if (!vala_code_node_check ((ValaCodeNode*) member, analyzer)) {
-		gboolean _tmp76;
-		return (_tmp76 = FALSE, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp76);
+		gboolean _tmp77;
+		return (_tmp77 = FALSE, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp77);
 	}
 	if (VALA_IS_FIELD (member)) {
-		ValaField* _tmp77;
+		ValaField* _tmp78;
 		ValaField* f;
-		_tmp77 = NULL;
-		f = (_tmp77 = VALA_FIELD (member), (_tmp77 == NULL) ? NULL : vala_code_node_ref (_tmp77));
+		_tmp78 = NULL;
+		f = (_tmp78 = VALA_FIELD (member), (_tmp78 == NULL) ? NULL : vala_code_node_ref (_tmp78));
 		access = vala_symbol_get_access ((ValaSymbol*) f);
 		instance = (vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE);
 		klass = (vala_field_get_binding (f) == MEMBER_BINDING_CLASS);
 		(f == NULL) ? NULL : (f = (vala_code_node_unref (f), NULL));
 	} else {
 		if (VALA_IS_METHOD (member)) {
-			ValaMethod* _tmp78;
+			ValaMethod* _tmp79;
 			ValaMethod* m;
-			_tmp78 = NULL;
-			m = (_tmp78 = VALA_METHOD (member), (_tmp78 == NULL) ? NULL : vala_code_node_ref (_tmp78));
+			_tmp79 = NULL;
+			m = (_tmp79 = VALA_METHOD (member), (_tmp79 == NULL) ? NULL : vala_code_node_ref (_tmp79));
 			access = vala_symbol_get_access ((ValaSymbol*) m);
 			if (!(VALA_IS_CREATION_METHOD (m))) {
 				instance = (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE);
@@ -841,67 +844,67 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
 		} else {
 			if (VALA_IS_PROPERTY (member)) {
-				ValaProperty* _tmp79;
+				ValaProperty* _tmp80;
 				ValaProperty* prop;
-				_tmp79 = NULL;
-				prop = (_tmp79 = VALA_PROPERTY (member), (_tmp79 == NULL) ? NULL : vala_code_node_ref (_tmp79));
+				_tmp80 = NULL;
+				prop = (_tmp80 = VALA_PROPERTY (member), (_tmp80 == NULL) ? NULL : vala_code_node_ref (_tmp80));
 				if (!vala_code_node_check ((ValaCodeNode*) prop, analyzer)) {
-					gboolean _tmp80;
+					gboolean _tmp81;
 					vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
-					return (_tmp80 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp80);
+					return (_tmp81 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp81);
 				}
 				access = vala_symbol_get_access ((ValaSymbol*) prop);
 				if (vala_expression_get_lvalue ((ValaExpression*) self)) {
 					if (vala_property_get_set_accessor (prop) == NULL) {
+						char* _tmp83;
 						char* _tmp82;
-						char* _tmp81;
-						gboolean _tmp83;
+						gboolean _tmp84;
 						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+						_tmp83 = NULL;
 						_tmp82 = NULL;
-						_tmp81 = NULL;
-						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp82 = g_strdup_printf ("Property `%s' is read-only", _tmp81 = vala_symbol_get_full_name ((ValaSymbol*) prop)));
+						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp83 = g_strdup_printf ("Property `%s' is read-only", _tmp82 = vala_symbol_get_full_name ((ValaSymbol*) prop)));
+						_tmp83 = (g_free (_tmp83), NULL);
 						_tmp82 = (g_free (_tmp82), NULL);
-						_tmp81 = (g_free (_tmp81), NULL);
-						return (_tmp83 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp83);
+						return (_tmp84 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp84);
 					}
 					if (vala_symbol_get_access ((ValaSymbol*) prop) == VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
 						access = vala_property_accessor_get_access (vala_property_get_set_accessor (prop));
 					} else {
-						gboolean _tmp84;
-						_tmp84 = FALSE;
+						gboolean _tmp85;
+						_tmp85 = FALSE;
 						if (vala_symbol_get_access ((ValaSymbol*) prop) == VALA_SYMBOL_ACCESSIBILITY_PROTECTED) {
-							_tmp84 = vala_property_accessor_get_access (vala_property_get_set_accessor (prop)) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC;
+							_tmp85 = vala_property_accessor_get_access (vala_property_get_set_accessor (prop)) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC;
 						} else {
-							_tmp84 = FALSE;
+							_tmp85 = FALSE;
 						}
-						if (_tmp84) {
+						if (_tmp85) {
 							access = vala_property_accessor_get_access (vala_property_get_set_accessor (prop));
 						}
 					}
 				} else {
 					if (vala_property_get_get_accessor (prop) == NULL) {
+						char* _tmp87;
 						char* _tmp86;
-						char* _tmp85;
-						gboolean _tmp87;
+						gboolean _tmp88;
 						vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+						_tmp87 = NULL;
 						_tmp86 = NULL;
-						_tmp85 = NULL;
-						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp86 = g_strdup_printf ("Property `%s' is write-only", _tmp85 = vala_symbol_get_full_name ((ValaSymbol*) prop)));
+						vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp87 = g_strdup_printf ("Property `%s' is write-only", _tmp86 = vala_symbol_get_full_name ((ValaSymbol*) prop)));
+						_tmp87 = (g_free (_tmp87), NULL);
 						_tmp86 = (g_free (_tmp86), NULL);
-						_tmp85 = (g_free (_tmp85), NULL);
-						return (_tmp87 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp87);
+						return (_tmp88 = FALSE, (prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp88);
 					}
 					if (vala_symbol_get_access ((ValaSymbol*) prop) == VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
 						access = vala_property_accessor_get_access (vala_property_get_get_accessor (prop));
 					} else {
-						gboolean _tmp88;
-						_tmp88 = FALSE;
+						gboolean _tmp89;
+						_tmp89 = FALSE;
 						if (vala_symbol_get_access ((ValaSymbol*) prop) == VALA_SYMBOL_ACCESSIBILITY_PROTECTED) {
-							_tmp88 = vala_property_accessor_get_access (vala_property_get_get_accessor (prop)) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC;
+							_tmp89 = vala_property_accessor_get_access (vala_property_get_get_accessor (prop)) != VALA_SYMBOL_ACCESSIBILITY_PUBLIC;
 						} else {
-							_tmp88 = FALSE;
+							_tmp89 = FALSE;
 						}
-						if (_tmp88) {
+						if (_tmp89) {
 							access = vala_property_accessor_get_access (vala_property_get_get_accessor (prop));
 						}
 					}
@@ -917,22 +920,22 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 	}
 	vala_symbol_set_used (member, TRUE);
 	if (access == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
-		ValaSymbol* _tmp89;
+		ValaSymbol* _tmp90;
 		ValaSymbol* target_type;
 		gboolean in_target_type;
-		_tmp89 = NULL;
-		target_type = (_tmp89 = vala_symbol_get_parent_symbol (member), (_tmp89 == NULL) ? NULL : vala_code_node_ref (_tmp89));
+		_tmp90 = NULL;
+		target_type = (_tmp90 = vala_symbol_get_parent_symbol (member), (_tmp90 == NULL) ? NULL : vala_code_node_ref (_tmp90));
 		in_target_type = FALSE;
 		{
-			ValaSymbol* _tmp90;
-			ValaSymbol* this_symbol;
-			ValaSymbol* _tmp92;
 			ValaSymbol* _tmp91;
-			_tmp90 = NULL;
-			this_symbol = (_tmp90 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp90 == NULL) ? NULL : vala_code_node_ref (_tmp90));
-			_tmp92 = NULL;
+			ValaSymbol* this_symbol;
+			ValaSymbol* _tmp93;
+			ValaSymbol* _tmp92;
 			_tmp91 = NULL;
-			for (; this_symbol != NULL; this_symbol = (_tmp92 = (_tmp91 = vala_symbol_get_parent_symbol (this_symbol), (_tmp91 == NULL) ? NULL : vala_code_node_ref (_tmp91)), (this_symbol == NULL) ? NULL : (this_symbol = (vala_code_node_unref (this_symbol), NULL)), _tmp92)) {
+			this_symbol = (_tmp91 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp91 == NULL) ? NULL : vala_code_node_ref (_tmp91));
+			_tmp93 = NULL;
+			_tmp92 = NULL;
+			for (; this_symbol != NULL; this_symbol = (_tmp93 = (_tmp92 = vala_symbol_get_parent_symbol (this_symbol), (_tmp92 == NULL) ? NULL : vala_code_node_ref (_tmp92)), (this_symbol == NULL) ? NULL : (this_symbol = (vala_code_node_unref (this_symbol), NULL)), _tmp93)) {
 				if (target_type == this_symbol) {
 					in_target_type = TRUE;
 					break;
@@ -941,213 +944,213 @@ static gboolean vala_member_access_real_check (ValaCodeNode* base, ValaSemanticA
 			(this_symbol == NULL) ? NULL : (this_symbol = (vala_code_node_unref (this_symbol), NULL));
 		}
 		if (!in_target_type) {
+			char* _tmp95;
 			char* _tmp94;
-			char* _tmp93;
-			gboolean _tmp95;
+			gboolean _tmp96;
 			vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
+			_tmp95 = NULL;
 			_tmp94 = NULL;
-			_tmp93 = NULL;
-			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp94 = g_strdup_printf ("Access to private member `%s' denied", _tmp93 = vala_symbol_get_full_name (member)));
+			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), _tmp95 = g_strdup_printf ("Access to private member `%s' denied", _tmp94 = vala_symbol_get_full_name (member)));
+			_tmp95 = (g_free (_tmp95), NULL);
 			_tmp94 = (g_free (_tmp94), NULL);
-			_tmp93 = (g_free (_tmp93), NULL);
-			return (_tmp95 = FALSE, (target_type == NULL) ? NULL : (target_type = (vala_code_node_unref (target_type), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp95);
+			return (_tmp96 = FALSE, (target_type == NULL) ? NULL : (target_type = (vala_code_node_unref (target_type), NULL)), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp96);
 		}
 		(target_type == NULL) ? NULL : (target_type = (vala_code_node_unref (target_type), NULL));
 	}
-	_tmp96 = FALSE;
 	_tmp97 = FALSE;
+	_tmp98 = FALSE;
 	if (instance) {
-		_tmp97 = TRUE;
+		_tmp98 = TRUE;
 	} else {
-		_tmp97 = klass;
+		_tmp98 = klass;
 	}
-	if ((_tmp97)) {
-		_tmp96 = !may_access_instance_members;
+	if ((_tmp98)) {
+		_tmp97 = !may_access_instance_members;
 	} else {
-		_tmp96 = FALSE;
+		_tmp97 = FALSE;
 	}
-	if (_tmp96) {
+	if (_tmp97) {
 		vala_member_access_set_prototype_access (self, TRUE);
 		if (VALA_IS_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-			ValaDataType* _tmp98;
+			ValaDataType* _tmp99;
 			/* also set static type for prototype access
 			 required when using instance methods as delegates in constants
 			 TODO replace by MethodPrototype*/
-			_tmp98 = NULL;
-			vala_expression_set_value_type ((ValaExpression*) self, _tmp98 = vala_semantic_analyzer_get_value_type_for_symbol (analyzer, vala_expression_get_symbol_reference ((ValaExpression*) self), vala_expression_get_lvalue ((ValaExpression*) self)));
-			(_tmp98 == NULL) ? NULL : (_tmp98 = (vala_code_node_unref (_tmp98), NULL));
+			_tmp99 = NULL;
+			vala_expression_set_value_type ((ValaExpression*) self, _tmp99 = vala_semantic_analyzer_get_value_type_for_symbol (analyzer, vala_expression_get_symbol_reference ((ValaExpression*) self), vala_expression_get_lvalue ((ValaExpression*) self)));
+			(_tmp99 == NULL) ? NULL : (_tmp99 = (vala_code_node_unref (_tmp99), NULL));
 		} else {
 			if (VALA_IS_FIELD (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-				ValaFieldPrototype* _tmp99;
-				_tmp99 = NULL;
-				vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp99 = vala_field_prototype_new (VALA_FIELD (vala_expression_get_symbol_reference ((ValaExpression*) self)))));
-				(_tmp99 == NULL) ? NULL : (_tmp99 = (vala_code_node_unref (_tmp99), NULL));
-			} else {
-				ValaInvalidType* _tmp100;
+				ValaFieldPrototype* _tmp100;
 				_tmp100 = NULL;
-				vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp100 = vala_invalid_type_new ()));
+				vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp100 = vala_field_prototype_new (VALA_FIELD (vala_expression_get_symbol_reference ((ValaExpression*) self)))));
 				(_tmp100 == NULL) ? NULL : (_tmp100 = (vala_code_node_unref (_tmp100), NULL));
+			} else {
+				ValaInvalidType* _tmp101;
+				_tmp101 = NULL;
+				vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp101 = vala_invalid_type_new ()));
+				(_tmp101 == NULL) ? NULL : (_tmp101 = (vala_code_node_unref (_tmp101), NULL));
 			}
 		}
 	} else {
-		gboolean _tmp101;
-		ValaDataType* _tmp104;
-		gboolean _tmp105;
-		_tmp101 = FALSE;
+		gboolean _tmp102;
+		ValaDataType* _tmp105;
+		gboolean _tmp106;
+		_tmp102 = FALSE;
 		if (instance) {
-			_tmp101 = vala_member_access_get_inner (self) == NULL;
+			_tmp102 = vala_member_access_get_inner (self) == NULL;
 		} else {
-			_tmp101 = FALSE;
+			_tmp102 = FALSE;
 		}
 		/* implicit this access*/
-		if (_tmp101) {
-			ValaMemberAccess* _tmp102;
-			ValaDataType* _tmp103;
-			_tmp102 = NULL;
-			vala_member_access_set_inner (self, (ValaExpression*) (_tmp102 = vala_member_access_new (NULL, "this", vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-			(_tmp102 == NULL) ? NULL : (_tmp102 = (vala_code_node_unref (_tmp102), NULL));
+		if (_tmp102) {
+			ValaMemberAccess* _tmp103;
+			ValaDataType* _tmp104;
 			_tmp103 = NULL;
-			vala_expression_set_value_type (vala_member_access_get_inner (self), _tmp103 = vala_data_type_copy (vala_formal_parameter_get_parameter_type (this_parameter)));
+			vala_member_access_set_inner (self, (ValaExpression*) (_tmp103 = vala_member_access_new (NULL, "this", vala_code_node_get_source_reference ((ValaCodeNode*) self))));
 			(_tmp103 == NULL) ? NULL : (_tmp103 = (vala_code_node_unref (_tmp103), NULL));
+			_tmp104 = NULL;
+			vala_expression_set_value_type (vala_member_access_get_inner (self), _tmp104 = vala_data_type_copy (vala_formal_parameter_get_parameter_type (this_parameter)));
+			(_tmp104 == NULL) ? NULL : (_tmp104 = (vala_code_node_unref (_tmp104), NULL));
 			vala_expression_set_symbol_reference (vala_member_access_get_inner (self), (ValaSymbol*) this_parameter);
 		}
-		_tmp104 = NULL;
-		vala_expression_set_formal_value_type ((ValaExpression*) self, _tmp104 = vala_semantic_analyzer_get_value_type_for_symbol (analyzer, vala_expression_get_symbol_reference ((ValaExpression*) self), vala_expression_get_lvalue ((ValaExpression*) self)));
-		(_tmp104 == NULL) ? NULL : (_tmp104 = (vala_code_node_unref (_tmp104), NULL));
-		_tmp105 = FALSE;
+		_tmp105 = NULL;
+		vala_expression_set_formal_value_type ((ValaExpression*) self, _tmp105 = vala_semantic_analyzer_get_value_type_for_symbol (analyzer, vala_expression_get_symbol_reference ((ValaExpression*) self), vala_expression_get_lvalue ((ValaExpression*) self)));
+		(_tmp105 == NULL) ? NULL : (_tmp105 = (vala_code_node_unref (_tmp105), NULL));
+		_tmp106 = FALSE;
 		if (vala_member_access_get_inner (self) != NULL) {
-			_tmp105 = vala_expression_get_formal_value_type ((ValaExpression*) self) != NULL;
+			_tmp106 = vala_expression_get_formal_value_type ((ValaExpression*) self) != NULL;
 		} else {
-			_tmp105 = FALSE;
+			_tmp106 = FALSE;
 		}
-		if (_tmp105) {
-			ValaDataType* _tmp106;
-			_tmp106 = NULL;
-			vala_expression_set_value_type ((ValaExpression*) self, _tmp106 = vala_data_type_get_actual_type (vala_expression_get_formal_value_type ((ValaExpression*) self), vala_expression_get_value_type (vala_member_access_get_inner (self)), (ValaCodeNode*) self));
-			(_tmp106 == NULL) ? NULL : (_tmp106 = (vala_code_node_unref (_tmp106), NULL));
+		if (_tmp106) {
+			ValaDataType* _tmp107;
+			_tmp107 = NULL;
+			vala_expression_set_value_type ((ValaExpression*) self, _tmp107 = vala_data_type_get_actual_type (vala_expression_get_formal_value_type ((ValaExpression*) self), vala_expression_get_value_type (vala_member_access_get_inner (self)), (ValaCodeNode*) self));
+			(_tmp107 == NULL) ? NULL : (_tmp107 = (vala_code_node_unref (_tmp107), NULL));
 		} else {
 			vala_expression_set_value_type ((ValaExpression*) self, vala_expression_get_formal_value_type ((ValaExpression*) self));
 		}
 		if (VALA_IS_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-			ValaMethod* _tmp107;
+			ValaMethod* _tmp108;
 			ValaMethod* m;
 			ValaMethod* base_method;
-			gboolean _tmp114;
-			_tmp107 = NULL;
-			m = (_tmp107 = VALA_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp107 == NULL) ? NULL : vala_code_node_ref (_tmp107));
+			gboolean _tmp115;
+			_tmp108 = NULL;
+			m = (_tmp108 = VALA_METHOD (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp108 == NULL) ? NULL : vala_code_node_ref (_tmp108));
 			base_method = NULL;
 			if (vala_method_get_base_method (m) != NULL) {
+				ValaMethod* _tmp110;
 				ValaMethod* _tmp109;
-				ValaMethod* _tmp108;
+				_tmp110 = NULL;
 				_tmp109 = NULL;
-				_tmp108 = NULL;
-				base_method = (_tmp109 = (_tmp108 = vala_method_get_base_method (m), (_tmp108 == NULL) ? NULL : vala_code_node_ref (_tmp108)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp109);
+				base_method = (_tmp110 = (_tmp109 = vala_method_get_base_method (m), (_tmp109 == NULL) ? NULL : vala_code_node_ref (_tmp109)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp110);
 			} else {
 				if (vala_method_get_base_interface_method (m) != NULL) {
-					ValaMethod* _tmp111;
-					ValaMethod* _tmp110;
-					_tmp111 = NULL;
-					_tmp110 = NULL;
-					base_method = (_tmp111 = (_tmp110 = vala_method_get_base_interface_method (m), (_tmp110 == NULL) ? NULL : vala_code_node_ref (_tmp110)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp111);
-				} else {
-					ValaMethod* _tmp113;
 					ValaMethod* _tmp112;
-					_tmp113 = NULL;
+					ValaMethod* _tmp111;
 					_tmp112 = NULL;
-					base_method = (_tmp113 = (_tmp112 = m, (_tmp112 == NULL) ? NULL : vala_code_node_ref (_tmp112)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp113);
+					_tmp111 = NULL;
+					base_method = (_tmp112 = (_tmp111 = vala_method_get_base_interface_method (m), (_tmp111 == NULL) ? NULL : vala_code_node_ref (_tmp111)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp112);
+				} else {
+					ValaMethod* _tmp114;
+					ValaMethod* _tmp113;
+					_tmp114 = NULL;
+					_tmp113 = NULL;
+					base_method = (_tmp114 = (_tmp113 = m, (_tmp113 == NULL) ? NULL : vala_code_node_ref (_tmp113)), (base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL)), _tmp114);
 				}
 			}
-			_tmp114 = FALSE;
+			_tmp115 = FALSE;
 			if (instance) {
-				_tmp114 = vala_symbol_get_parent_symbol ((ValaSymbol*) base_method) != NULL;
+				_tmp115 = vala_symbol_get_parent_symbol ((ValaSymbol*) base_method) != NULL;
 			} else {
-				_tmp114 = FALSE;
+				_tmp115 = FALSE;
 			}
-			if (_tmp114) {
-				ValaDataType* _tmp115;
-				_tmp115 = NULL;
-				vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp115 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol ((ValaSymbol*) base_method))));
-				(_tmp115 == NULL) ? NULL : (_tmp115 = (vala_code_node_unref (_tmp115), NULL));
+			if (_tmp115) {
+				ValaDataType* _tmp116;
+				_tmp116 = NULL;
+				vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp116 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol ((ValaSymbol*) base_method))));
+				(_tmp116 == NULL) ? NULL : (_tmp116 = (vala_code_node_unref (_tmp116), NULL));
 			}
 			(m == NULL) ? NULL : (m = (vala_code_node_unref (m), NULL));
 			(base_method == NULL) ? NULL : (base_method = (vala_code_node_unref (base_method), NULL));
 		} else {
 			if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-				ValaProperty* _tmp116;
+				ValaProperty* _tmp117;
 				ValaProperty* prop;
 				ValaProperty* base_property;
-				gboolean _tmp123;
-				_tmp116 = NULL;
-				prop = (_tmp116 = VALA_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp116 == NULL) ? NULL : vala_code_node_ref (_tmp116));
+				gboolean _tmp124;
+				_tmp117 = NULL;
+				prop = (_tmp117 = VALA_PROPERTY (vala_expression_get_symbol_reference ((ValaExpression*) self)), (_tmp117 == NULL) ? NULL : vala_code_node_ref (_tmp117));
 				base_property = NULL;
 				if (vala_property_get_base_property (prop) != NULL) {
+					ValaProperty* _tmp119;
 					ValaProperty* _tmp118;
-					ValaProperty* _tmp117;
+					_tmp119 = NULL;
 					_tmp118 = NULL;
-					_tmp117 = NULL;
-					base_property = (_tmp118 = (_tmp117 = vala_property_get_base_property (prop), (_tmp117 == NULL) ? NULL : vala_code_node_ref (_tmp117)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp118);
+					base_property = (_tmp119 = (_tmp118 = vala_property_get_base_property (prop), (_tmp118 == NULL) ? NULL : vala_code_node_ref (_tmp118)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp119);
 				} else {
 					if (vala_property_get_base_interface_property (prop) != NULL) {
-						ValaProperty* _tmp120;
-						ValaProperty* _tmp119;
-						_tmp120 = NULL;
-						_tmp119 = NULL;
-						base_property = (_tmp120 = (_tmp119 = vala_property_get_base_interface_property (prop), (_tmp119 == NULL) ? NULL : vala_code_node_ref (_tmp119)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp120);
-					} else {
-						ValaProperty* _tmp122;
 						ValaProperty* _tmp121;
-						_tmp122 = NULL;
+						ValaProperty* _tmp120;
 						_tmp121 = NULL;
-						base_property = (_tmp122 = (_tmp121 = prop, (_tmp121 == NULL) ? NULL : vala_code_node_ref (_tmp121)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp122);
+						_tmp120 = NULL;
+						base_property = (_tmp121 = (_tmp120 = vala_property_get_base_interface_property (prop), (_tmp120 == NULL) ? NULL : vala_code_node_ref (_tmp120)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp121);
+					} else {
+						ValaProperty* _tmp123;
+						ValaProperty* _tmp122;
+						_tmp123 = NULL;
+						_tmp122 = NULL;
+						base_property = (_tmp123 = (_tmp122 = prop, (_tmp122 == NULL) ? NULL : vala_code_node_ref (_tmp122)), (base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL)), _tmp123);
 					}
 				}
-				_tmp123 = FALSE;
+				_tmp124 = FALSE;
 				if (instance) {
-					_tmp123 = vala_symbol_get_parent_symbol ((ValaSymbol*) base_property) != NULL;
+					_tmp124 = vala_symbol_get_parent_symbol ((ValaSymbol*) base_property) != NULL;
 				} else {
-					_tmp123 = FALSE;
+					_tmp124 = FALSE;
 				}
-				if (_tmp123) {
-					ValaDataType* _tmp124;
-					_tmp124 = NULL;
-					vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp124 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol ((ValaSymbol*) base_property))));
-					(_tmp124 == NULL) ? NULL : (_tmp124 = (vala_code_node_unref (_tmp124), NULL));
+				if (_tmp124) {
+					ValaDataType* _tmp125;
+					_tmp125 = NULL;
+					vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp125 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol ((ValaSymbol*) base_property))));
+					(_tmp125 == NULL) ? NULL : (_tmp125 = (vala_code_node_unref (_tmp125), NULL));
 				}
 				(prop == NULL) ? NULL : (prop = (vala_code_node_unref (prop), NULL));
 				(base_property == NULL) ? NULL : (base_property = (vala_code_node_unref (base_property), NULL));
 			} else {
-				gboolean _tmp125;
 				gboolean _tmp126;
 				gboolean _tmp127;
-				_tmp125 = FALSE;
+				gboolean _tmp128;
 				_tmp126 = FALSE;
 				_tmp127 = FALSE;
+				_tmp128 = FALSE;
 				if (VALA_IS_FIELD (vala_expression_get_symbol_reference ((ValaExpression*) self))) {
-					_tmp127 = TRUE;
+					_tmp128 = TRUE;
 				} else {
-					_tmp127 = VALA_IS_SIGNAL (vala_expression_get_symbol_reference ((ValaExpression*) self));
+					_tmp128 = VALA_IS_SIGNAL (vala_expression_get_symbol_reference ((ValaExpression*) self));
 				}
-				if ((_tmp127)) {
-					_tmp126 = instance;
+				if ((_tmp128)) {
+					_tmp127 = instance;
+				} else {
+					_tmp127 = FALSE;
+				}
+				if (_tmp127) {
+					_tmp126 = vala_symbol_get_parent_symbol (vala_expression_get_symbol_reference ((ValaExpression*) self)) != NULL;
 				} else {
 					_tmp126 = FALSE;
 				}
 				if (_tmp126) {
-					_tmp125 = vala_symbol_get_parent_symbol (vala_expression_get_symbol_reference ((ValaExpression*) self)) != NULL;
-				} else {
-					_tmp125 = FALSE;
-				}
-				if (_tmp125) {
-					ValaDataType* _tmp128;
-					_tmp128 = NULL;
-					vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp128 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (vala_expression_get_symbol_reference ((ValaExpression*) self)))));
-					(_tmp128 == NULL) ? NULL : (_tmp128 = (vala_code_node_unref (_tmp128), NULL));
+					ValaDataType* _tmp129;
+					_tmp129 = NULL;
+					vala_expression_set_target_type (vala_member_access_get_inner (self), _tmp129 = vala_semantic_analyzer_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (vala_expression_get_symbol_reference ((ValaExpression*) self)))));
+					(_tmp129 == NULL) ? NULL : (_tmp129 = (vala_code_node_unref (_tmp129), NULL));
 				}
 			}
 		}
 	}
 	vala_source_file_add_symbol_dependency (vala_semantic_analyzer_get_current_source_file (analyzer), vala_expression_get_symbol_reference ((ValaExpression*) self), VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE);
-	return (_tmp129 = !vala_code_node_get_error ((ValaCodeNode*) self), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp129);
+	return (_tmp130 = !vala_code_node_get_error ((ValaCodeNode*) self), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), (this_parameter == NULL) ? NULL : (this_parameter = (vala_code_node_unref (this_parameter), NULL)), (member == NULL) ? NULL : (member = (vala_code_node_unref (member), NULL)), _tmp130);
 }
 
 
