@@ -23,29 +23,30 @@
  */
 
 #include <vala/valamethod.h>
-#include <gee/readonlylist.h>
 #include <gee/arraylist.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
-#include <gee/collection.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaformalparameter.h>
-#include <vala/valablock.h>
 #include <vala/valasymbol.h>
-#include <vala/valaattribute.h>
+#include <vala/valaformalparameter.h>
+#include <vala/valascope.h>
+#include <vala/valaexpression.h>
+#include <vala/valalocalvariable.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valasemanticanalyzer.h>
+#include <vala/valaattribute.h>
 #include <vala/valaclass.h>
 #include <vala/valareport.h>
 #include <vala/valainterface.h>
+#include <vala/valablock.h>
 #include <vala/valasourcefile.h>
 #include <vala/valastruct.h>
 #include <vala/valacodecontext.h>
 #include <vala/valavaluetype.h>
-#include <vala/valalocalvariable.h>
-#include <vala/valaexpression.h>
 #include <vala/valacreationmethod.h>
-#include <vala/valascope.h>
 #include <vala/valaobjecttype.h>
 #include <vala/valaobjecttypesymbol.h>
 #include <vala/valatypeparameter.h>
@@ -53,7 +54,6 @@
 #include <vala/valasignal.h>
 #include <vala/valavoidtype.h>
 #include <vala/valaarraytype.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valabasicblock.h>
 
 
@@ -681,8 +681,8 @@ static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
-			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get ((GeeList*) error_types, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
-				gee_list_set ((GeeList*) error_types, i, new_type);
+			if ((_tmp1 = (_tmp0 = (ValaDataType*) gee_list_get (error_types, i)) == old_type, (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1)) {
+				gee_list_set (error_types, i, new_type);
 				(error_types == NULL) ? NULL : (error_types = (gee_collection_object_unref (error_types), NULL));
 				return;
 			}
