@@ -1,6 +1,6 @@
 /* valapointertype.vala
  *
- * Copyright (C) 2007-2008  Jürg Billeter
+ * Copyright (C) 2007-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,6 @@
 #include <vala/valapointertype.h>
 #include <vala/valacodenode.h>
 #include <vala/valatypesymbol.h>
-#include <vala/valasemanticanalyzer.h>
 
 
 
@@ -46,6 +45,7 @@ static char* vala_pointer_type_real_get_type_id (ValaDataType* base);
 static void vala_pointer_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gboolean vala_pointer_type_real_is_disposable (ValaDataType* base);
+static gboolean vala_pointer_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_pointer_type_parent_class = NULL;
 static void vala_pointer_type_finalize (ValaCodeNode* obj);
 
@@ -53,12 +53,11 @@ static void vala_pointer_type_finalize (ValaCodeNode* obj);
 
 ValaPointerType* vala_pointer_type_construct (GType object_type, ValaDataType* base_type, ValaSourceReference* source_reference) {
 	ValaPointerType* self;
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (base_type), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	self = ((ValaPointerType*) (g_type_create_instance (object_type)));
+	g_return_val_if_fail (base_type != NULL, NULL);
+	self = (ValaPointerType*) g_type_create_instance (object_type);
 	vala_pointer_type_set_base_type (self, base_type);
-	vala_data_type_set_nullable (VALA_DATA_TYPE (self), TRUE);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_data_type_set_nullable ((ValaDataType*) self, TRUE);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source_reference);
 	return self;
 }
 
@@ -72,25 +71,31 @@ static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, Val
 	ValaPointerType * self;
 	char* _tmp0;
 	char* _tmp1;
-	self = VALA_POINTER_TYPE (base);
-	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
+	self = (ValaPointerType*) base;
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat ((_tmp0 = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope)), "*", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strconcat (_tmp0 = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
 }
 
 
 static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
-	if (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)) != NULL && vala_typesymbol_is_reference_type (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)))) {
+	gboolean _tmp0;
+	self = (ValaPointerType*) base;
+	_tmp0 = FALSE;
+	if (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)) != NULL) {
+		_tmp0 = vala_typesymbol_is_reference_type (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)));
+	} else {
+		_tmp0 = FALSE;
+	}
+	if (_tmp0) {
 		return vala_data_type_get_cname (vala_pointer_type_get_base_type (self));
 	} else {
-		char* _tmp1;
 		char* _tmp2;
-		_tmp1 = NULL;
+		char* _tmp3;
 		_tmp2 = NULL;
-		return (_tmp2 = g_strconcat ((_tmp1 = vala_data_type_get_cname (vala_pointer_type_get_base_type (self))), "*", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+		_tmp3 = NULL;
+		return (_tmp3 = g_strconcat (_tmp2 = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp2 = (g_free (_tmp2), NULL), _tmp3);
 	}
 }
 
@@ -99,21 +104,35 @@ static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base) {
 	ValaPointerType * self;
 	ValaDataType* _tmp0;
 	ValaDataType* _tmp1;
-	self = VALA_POINTER_TYPE (base);
+	self = (ValaPointerType*) base;
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = VALA_DATA_TYPE (vala_pointer_type_new ((_tmp0 = vala_data_type_copy (vala_pointer_type_get_base_type (self))), NULL)), (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1);
+	return (_tmp1 = (ValaDataType*) vala_pointer_type_new (_tmp0 = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1);
 }
 
 
 static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaPointerType * self;
-	ValaAttribute* _tmp0;
-	gboolean _tmp1;
-	self = VALA_POINTER_TYPE (base);
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
-	_tmp0 = NULL;
-	if ((_tmp1 = VALA_IS_POINTER_TYPE (target_type) || (vala_data_type_get_data_type (target_type) != NULL && (_tmp0 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL), (_tmp0 == NULL ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL))), _tmp1)) {
+	gboolean _tmp0;
+	self = (ValaPointerType*) base;
+	g_return_val_if_fail (target_type != NULL, FALSE);
+	_tmp0 = FALSE;
+	if (VALA_IS_POINTER_TYPE (target_type)) {
+		_tmp0 = TRUE;
+	} else {
+		gboolean _tmp1;
+		_tmp1 = FALSE;
+		if (vala_data_type_get_data_type (target_type) != NULL) {
+			ValaAttribute* _tmp2;
+			_tmp2 = NULL;
+			_tmp1 = (_tmp2 = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
+			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+		} else {
+			_tmp1 = FALSE;
+		}
+		_tmp0 = (_tmp1);
+	}
+	if (_tmp0) {
 		return TRUE;
 	}
 	/* temporarily ignore type parameters */
@@ -133,47 +152,47 @@ static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base
 	ValaSymbol* _tmp0;
 	ValaSymbol* base_symbol;
 	ValaSymbol* _tmp2;
-	self = VALA_POINTER_TYPE (base);
+	self = (ValaPointerType*) base;
 	g_return_val_if_fail (member_name != NULL, NULL);
 	_tmp0 = NULL;
-	base_symbol = (_tmp0 = VALA_SYMBOL (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self))), (_tmp0 == NULL ? NULL : vala_code_node_ref (_tmp0)));
+	base_symbol = (_tmp0 = (ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
 	if (base_symbol == NULL) {
 		ValaSymbol* _tmp1;
 		_tmp1 = NULL;
-		return (_tmp1 = NULL, (base_symbol == NULL ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL))), _tmp1);
+		return (_tmp1 = NULL, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp1);
 	}
 	_tmp2 = NULL;
-	return (_tmp2 = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name), (base_symbol == NULL ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL))), _tmp2);
+	return (_tmp2 = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp2);
 }
 
 
 static GeeList* vala_pointer_type_real_get_symbols (ValaDataType* base) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
+	self = (ValaPointerType*) base;
 	return vala_data_type_get_symbols (vala_pointer_type_get_base_type (self));
 }
 
 
 static char* vala_pointer_type_real_get_type_id (ValaDataType* base) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
+	self = (ValaPointerType*) base;
 	return g_strdup ("G_TYPE_POINTER");
 }
 
 
 static void vala_pointer_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_pointer_type_get_base_type (self)), visitor);
+	self = (ValaPointerType*) base;
+	g_return_if_fail (visitor != NULL);
+	vala_code_node_accept ((ValaCodeNode*) vala_pointer_type_get_base_type (self), visitor);
 }
 
 
 static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
-	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	self = (ValaPointerType*) base;
+	g_return_if_fail (old_type != NULL);
+	g_return_if_fail (new_type != NULL);
 	if (vala_pointer_type_get_base_type (self) == old_type) {
 		vala_pointer_type_set_base_type (self, new_type);
 	}
@@ -182,13 +201,22 @@ static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataTyp
 
 static gboolean vala_pointer_type_real_is_disposable (ValaDataType* base) {
 	ValaPointerType * self;
-	self = VALA_POINTER_TYPE (base);
+	self = (ValaPointerType*) base;
 	return FALSE;
 }
 
 
+static gboolean vala_pointer_type_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaPointerType * self;
+	self = (ValaPointerType*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	vala_code_node_set_error ((ValaCodeNode*) self, !vala_code_node_check ((ValaCodeNode*) vala_pointer_type_get_base_type (self), analyzer));
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
+}
+
+
 ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
-	g_return_val_if_fail (VALA_IS_POINTER_TYPE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_base_type;
 }
 
@@ -196,11 +224,11 @@ ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
 void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
-	g_return_if_fail (VALA_IS_POINTER_TYPE (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_base_type), VALA_CODE_NODE (self));
+	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2);
+	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_base_type, (ValaCodeNode*) self);
 }
 
 
@@ -218,6 +246,7 @@ static void vala_pointer_type_class_init (ValaPointerTypeClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_pointer_type_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_pointer_type_real_replace_type;
 	VALA_DATA_TYPE_CLASS (klass)->is_disposable = vala_pointer_type_real_is_disposable;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_pointer_type_real_check;
 }
 
 
@@ -229,7 +258,7 @@ static void vala_pointer_type_instance_init (ValaPointerType * self) {
 static void vala_pointer_type_finalize (ValaCodeNode* obj) {
 	ValaPointerType * self;
 	self = VALA_POINTER_TYPE (obj);
-	(self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)));
+	(self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL));
 	VALA_CODE_NODE_CLASS (vala_pointer_type_parent_class)->finalize (obj);
 }
 
