@@ -1,6 +1,6 @@
 /* valarealliteral.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,11 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaexpression.h>
+#include <vala/valasemanticanalyzer.h>
+#include <vala/valafloatingtype.h>
+#include <vala/valasymbol.h>
+#include <vala/valascope.h>
+#include <vala/valastruct.h>
 
 
 
@@ -39,6 +44,7 @@ enum  {
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_real_literal_real_is_pure (ValaExpression* base);
 static char* vala_real_literal_real_to_string (ValaCodeNode* base);
+static gboolean vala_real_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer);
 static gpointer vala_real_literal_parent_class = NULL;
 static void vala_real_literal_finalize (ValaCodeNode* obj);
 
@@ -54,10 +60,10 @@ static void vala_real_literal_finalize (ValaCodeNode* obj);
 ValaRealLiteral* vala_real_literal_construct (GType object_type, const char* r, ValaSourceReference* source) {
 	ValaRealLiteral* self;
 	g_return_val_if_fail (r != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
-	self = ((ValaRealLiteral*) (g_type_create_instance (object_type)));
+	g_return_val_if_fail (source != NULL, NULL);
+	self = (ValaRealLiteral*) g_type_create_instance (object_type);
 	vala_real_literal_set_value (self, r);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_code_node_set_source_reference ((ValaCodeNode*) self, source);
 	return self;
 }
 
@@ -69,10 +75,10 @@ ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* sour
 
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaRealLiteral * self;
-	self = VALA_REAL_LITERAL (base);
-	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	self = (ValaRealLiteral*) base;
+	g_return_if_fail (visitor != NULL);
 	vala_code_visitor_visit_real_literal (visitor, self);
-	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
+	vala_code_visitor_visit_expression (visitor, (ValaExpression*) self);
 }
 
 
@@ -82,8 +88,15 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  * @return the name of literal type
  */
 char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
-	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
-	if (g_str_has_suffix (self->priv->_value, "f") || g_str_has_suffix (self->priv->_value, "F")) {
+	gboolean _tmp0;
+	g_return_val_if_fail (self != NULL, NULL);
+	_tmp0 = FALSE;
+	if (g_str_has_suffix (self->priv->_value, "f")) {
+		_tmp0 = TRUE;
+	} else {
+		_tmp0 = g_str_has_suffix (self->priv->_value, "F");
+	}
+	if (_tmp0) {
 		return g_strdup ("float");
 	}
 	return g_strdup ("double");
@@ -92,7 +105,7 @@ char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 
 static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 	ValaRealLiteral * self;
-	self = VALA_REAL_LITERAL (base);
+	self = (ValaRealLiteral*) base;
 	return TRUE;
 }
 
@@ -100,14 +113,36 @@ static gboolean vala_real_literal_real_is_pure (ValaExpression* base) {
 static char* vala_real_literal_real_to_string (ValaCodeNode* base) {
 	ValaRealLiteral * self;
 	const char* _tmp0;
-	self = VALA_REAL_LITERAL (base);
+	self = (ValaRealLiteral*) base;
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	return (_tmp0 = self->priv->_value, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+}
+
+
+static gboolean vala_real_literal_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
+	ValaRealLiteral * self;
+	ValaFloatingType* _tmp3;
+	ValaStruct* _tmp2;
+	char* _tmp1;
+	self = (ValaRealLiteral*) base;
+	g_return_val_if_fail (analyzer != NULL, FALSE);
+	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
+		return !vala_code_node_get_error ((ValaCodeNode*) self);
+	}
+	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp3 = vala_floating_type_new (_tmp2 = VALA_STRUCT (vala_scope_lookup (vala_symbol_get_scope (analyzer->root_symbol), _tmp1 = vala_real_literal_get_type_name (self))))));
+	(_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL));
+	(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+	_tmp1 = (g_free (_tmp1), NULL);
+	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
 
 
 const char* vala_real_literal_get_value (ValaRealLiteral* self) {
-	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	return self->priv->_value;
 }
 
@@ -115,10 +150,10 @@ const char* vala_real_literal_get_value (ValaRealLiteral* self) {
 void vala_real_literal_set_value (ValaRealLiteral* self, const char* value) {
 	char* _tmp2;
 	const char* _tmp1;
-	g_return_if_fail (VALA_IS_REAL_LITERAL (self));
+	g_return_if_fail (self != NULL);
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_value = (g_free (self->priv->_value), NULL)), _tmp2);
+	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_value = (g_free (self->priv->_value), NULL), _tmp2);
 }
 
 
@@ -129,6 +164,7 @@ static void vala_real_literal_class_init (ValaRealLiteralClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_real_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_real_literal_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_real_literal_real_to_string;
+	VALA_CODE_NODE_CLASS (klass)->check = vala_real_literal_real_check;
 }
 
 
