@@ -37,65 +37,70 @@ enum  {
 };
 static gboolean vala_tuple_real_is_pure (ValaExpression* base);
 static gpointer vala_tuple_parent_class = NULL;
-static void vala_tuple_finalize (GObject * obj);
+static void vala_tuple_finalize (ValaCodeNode* obj);
 
 
 
-ValaTuple* vala_tuple_new (void) {
-	ValaTuple * self;
-	self = g_object_newv (VALA_TYPE_TUPLE, 0, NULL);
+ValaTuple* vala_tuple_construct (GType object_type) {
+	ValaTuple* self;
+	self = (ValaTuple*) g_type_create_instance (object_type);
 	return self;
 }
 
 
+ValaTuple* vala_tuple_new (void) {
+	return vala_tuple_construct (VALA_TYPE_TUPLE);
+}
+
+
 void vala_tuple_add_expression (ValaTuple* self, ValaExpression* expr) {
-	g_return_if_fail (VALA_IS_TUPLE (self));
-	g_return_if_fail (VALA_IS_EXPRESSION (expr));
-	gee_collection_add (GEE_COLLECTION (self->priv->expression_list), expr);
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (expr != NULL);
+	gee_collection_add ((GeeCollection*) self->priv->expression_list, expr);
 }
 
 
 GeeList* vala_tuple_get_expressions (ValaTuple* self) {
 	GeeList* _tmp0;
-	g_return_val_if_fail (VALA_IS_TUPLE (self), NULL);
+	g_return_val_if_fail (self != NULL, NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->expression_list, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	return (_tmp0 = self->priv->expression_list, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0));
 }
 
 
 static gboolean vala_tuple_real_is_pure (ValaExpression* base) {
 	ValaTuple * self;
-	self = VALA_TUPLE (base);
+	self = (ValaTuple*) base;
 	return FALSE;
 }
 
 
 static void vala_tuple_class_init (ValaTupleClass * klass) {
 	vala_tuple_parent_class = g_type_class_peek_parent (klass);
+	VALA_CODE_NODE_CLASS (klass)->finalize = vala_tuple_finalize;
 	g_type_class_add_private (klass, sizeof (ValaTuplePrivate));
-	G_OBJECT_CLASS (klass)->finalize = vala_tuple_finalize;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_tuple_real_is_pure;
 }
 
 
 static void vala_tuple_instance_init (ValaTuple * self) {
 	self->priv = VALA_TUPLE_GET_PRIVATE (self);
-	self->priv->expression_list = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->expression_list = (GeeList*) gee_array_list_new (VALA_TYPE_EXPRESSION, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal);
 }
 
 
-static void vala_tuple_finalize (GObject * obj) {
+static void vala_tuple_finalize (ValaCodeNode* obj) {
 	ValaTuple * self;
 	self = VALA_TUPLE (obj);
-	(self->priv->expression_list == NULL ? NULL : (self->priv->expression_list = (g_object_unref (self->priv->expression_list), NULL)));
-	G_OBJECT_CLASS (vala_tuple_parent_class)->finalize (obj);
+	(self->priv->expression_list == NULL) ? NULL : (self->priv->expression_list = (gee_collection_object_unref (self->priv->expression_list), NULL));
+	VALA_CODE_NODE_CLASS (vala_tuple_parent_class)->finalize (obj);
 }
 
 
 GType vala_tuple_get_type (void) {
 	static GType vala_tuple_type_id = 0;
 	if (vala_tuple_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTupleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_tuple_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTuple), 0, (GInstanceInitFunc) vala_tuple_instance_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTupleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_tuple_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTuple), 0, (GInstanceInitFunc) vala_tuple_instance_init, NULL };
 		vala_tuple_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaTuple", &g_define_type_info, 0);
 	}
 	return vala_tuple_type_id;
