@@ -90,6 +90,7 @@ static gpointer vala_vapi_gen_parent_class = NULL;
 static void vala_vapi_gen_finalize (GObject* obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 
 static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", (gchar) 0, 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"metadata", (gchar) 0, 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_metadata_filename, "Metadata filename", "FILE"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", (gchar) 0, 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 
@@ -140,7 +141,7 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 		/* ignore multiple occurences of the same package*/
 		return TRUE;
 	}
-	package_path = vala_code_context_get_package_path (self->priv->context, pkg, vala_vapi_gen_vapi_directories, g_strv_length (vala_vapi_gen_vapi_directories));
+	package_path = vala_code_context_get_package_path (self->priv->context, pkg, vala_vapi_gen_vapi_directories, _vala_array_length (vala_vapi_gen_vapi_directories));
 	if (package_path == NULL) {
 		gboolean _tmp1;
 		return (_tmp1 = FALSE, package_path = (g_free (package_path), NULL), _tmp1);
@@ -181,7 +182,7 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 		_tmp3 = NULL;
 		_tmp4 = NULL;
 		_tmp5 = NULL;
-		return (_tmp5 = (_tmp4 = _tmp3 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = g_strv_length (_tmp3), _tmp4), contents = (g_free (contents), NULL), _tmp5);
+		return (_tmp5 = (_tmp4 = _tmp3 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = _vala_array_length (_tmp3), _tmp4), contents = (g_free (contents), NULL), _tmp5);
 	}
 	goto __finally4;
 	__catch4_g_file_error:
@@ -231,8 +232,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		int source_collection_length1;
 		int source_it;
 		source_collection = vala_vapi_gen_sources;
-		source_collection_length1 = g_strv_length (vala_vapi_gen_sources);
-		for (source_it = 0; source_it < g_strv_length (vala_vapi_gen_sources); source_it = source_it + 1) {
+		source_collection_length1 = _vala_array_length (vala_vapi_gen_sources);
+		for (source_it = 0; source_it < _vala_array_length (vala_vapi_gen_sources); source_it = source_it + 1) {
 			const char* _tmp7;
 			char* source;
 			_tmp7 = NULL;
@@ -295,8 +296,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			int package_collection_length1;
 			int package_it;
 			package_collection = vala_vapi_gen_packages;
-			package_collection_length1 = g_strv_length (vala_vapi_gen_packages);
-			for (package_it = 0; package_it < g_strv_length (vala_vapi_gen_packages); package_it = package_it + 1) {
+			package_collection_length1 = _vala_array_length (vala_vapi_gen_packages);
+			for (package_it = 0; package_it < _vala_array_length (vala_vapi_gen_packages); package_it = package_it + 1) {
 				const char* _tmp9;
 				char* package;
 				_tmp9 = NULL;
@@ -313,7 +314,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			}
 		}
 		_tmp10 = NULL;
-		vala_vapi_gen_packages = (_tmp10 = NULL, vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, g_strv_length (vala_vapi_gen_packages), (GDestroyNotify) g_free), NULL), _tmp10);
+		vala_vapi_gen_packages = (_tmp10 = NULL, vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, _vala_array_length (vala_vapi_gen_packages), (GDestroyNotify) g_free), NULL), _tmp10);
 	}
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
@@ -323,8 +324,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		int source_collection_length1;
 		int source_it;
 		source_collection = vala_vapi_gen_sources;
-		source_collection_length1 = g_strv_length (vala_vapi_gen_sources);
-		for (source_it = 0; source_it < g_strv_length (vala_vapi_gen_sources); source_it = source_it + 1) {
+		source_collection_length1 = _vala_array_length (vala_vapi_gen_sources);
+		for (source_it = 0; source_it < _vala_array_length (vala_vapi_gen_sources); source_it = source_it + 1) {
 			const char* _tmp14;
 			char* source;
 			_tmp14 = NULL;
@@ -346,7 +347,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		}
 	}
 	_tmp15 = NULL;
-	vala_vapi_gen_sources = (_tmp15 = NULL, vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, g_strv_length (vala_vapi_gen_sources), (GDestroyNotify) g_free), NULL), _tmp15);
+	vala_vapi_gen_sources = (_tmp15 = NULL, vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, _vala_array_length (vala_vapi_gen_sources), (GDestroyNotify) g_free), NULL), _tmp15);
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
 	}
@@ -533,5 +534,17 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 
 
